###################################################
### chunk number 1: load-limma
###################################################
library(limma)


###################################################
### chunk number 2: readTargets
###################################################
targets <- readTargets("coralTargets.txt")
targets$FileName     # Display the file names


###################################################
### chunk number 3: see-targets eval=FALSE
###################################################
## targets


###################################################
### chunk number 4: read-images
###################################################
coralRG <- read.maimages(targets$FileName, source = "spot",
    other.columns=list(area="area", badspot="badspot"))


###################################################
### chunk number 5: 
###################################################
summary(coralRG$other$area)


###################################################
### chunk number 6: 
###################################################
plot(density(coralRG$other$area[,1]))


###################################################
### chunk number 7: 
###################################################
coralRG$genes <- readGAL()
coralRG$printer <- getLayout(coralRG$genes)
coralRG$printer


###################################################
### chunk number 8: printseq
###################################################
library(DAAGbio)
plotprintseq()


###################################################
### chunk number 9: 
###################################################
spottypes<-readSpotTypes()
coralRG$genes$Status <- controlStatus(spottypes, coralRG)


###################################################
### chunk number 10: 
###################################################
imageplot(log2(coralRG$Rb[, 1]+1), layout = coralRG$printer,
          low="white", high="red")


###################################################
### chunk number 11: 
###################################################
imageplot(log2(coralRG$Rb[, 2]+1), layout = coralRG$printer,
          low="white", high="red")


###################################################
### chunk number 12: 
###################################################
plotMA(coralRG, array=1)


###################################################
### chunk number 13: 
###################################################
rawMA <- normalizeWithinArrays(coralRG, method = "none")
plotPrintTipLoess(rawMA, array=1)


###################################################
### chunk number 14: 
###################################################
MA <- normalizeWithinArrays(coralRG, method = "printtiploess")
plotPrintTipLoess(MA)


###################################################
### chunk number 15:  eval=FALSE
###################################################
## boxplot(MA$M ~ col(MA$M), names = colnames(MA$M))


###################################################
### chunk number 16: 
###################################################
nMA <- normalizeBetweenArrays(MA)
boxplot(nMA$M ~ col(nMA$M), names = colnames(nMA$M))


###################################################
### chunk number 17: 
###################################################
wanted <- coralRG$genes$Status == "diff-exp ctl"
rawdeM <- rawMA$M[wanted, ]
pairs(rawdeM)


###################################################
### chunk number 18: 
###################################################
wanted <- coralRG$genes$Status == "diff-exp ctl"
deM <- nMA$M[wanted, ]
pairs(rawdeM)


###################################################
### chunk number 19: 
###################################################
imageplot(nMA$M[,5], layout=coralRG$printer)


###################################################
### chunk number 20: 
###################################################
design <- c(-1, 1, -1, 1, 0, 1)


###################################################
### chunk number 21: 
###################################################
fit <- lmFit(nMA, design)


###################################################
### chunk number 22: 
###################################################
efit <- eBayes(fit)
qqt(efit$t, df = efit$df.prior + efit$df.residual, pch = 16, 
    cex = 0.2)


###################################################
### chunk number 23: 
###################################################
options(digits = 3)
topvals <- topTable(efit, number = 50)
topvals


###################################################
### chunk number 24: 
###################################################
plot(efit$coef, efit$lods, pch = 16, cex = 0.2, xlab = "log(fold change)", 
    ylab = "log(odds)")
ord <- order(efit$lods, decreasing = TRUE)
top8 <- ord[1:8]
text(efit$coef[top8], efit$lods[top8], labels = coralRG$genes[top8, 
    "Name"], cex = 0.8, col = "blue")


###################################################
### chunk number 25: 
###################################################
coral2RG <- read.maimages(targets$FileName, 
                         source = "spot",
                         wt.fun=wtarea(100))
coral2RG$genes <- readGAL()
coral2RG$printer <- getLayout(coral2RG$genes)


###################################################
### chunk number 26: 
###################################################
MA2 <- normalizeWithinArrays(coral2RG, method = "printtiploess")
plotPrintTipLoess(MA2)


###################################################
### chunk number 27: 
###################################################
boxplot(MA2$M ~ col(MA2$M), names = colnames(MA2$M))
nMA2 <- normalizeBetweenArrays(MA2)
boxplot(nMA2$M ~ col(nMA2$M), names = colnames(nMA2$M))


###################################################
### chunk number 28: 
###################################################
imageplot(nMA2$M[,5], layout=coral2RG$printer)


###################################################
### chunk number 29: 
###################################################
design <- c(-1, 1, -1, 1, 0, 1)
fit2 <- lmFit(nMA2, design)


###################################################
### chunk number 30: 
###################################################
efit2 <- eBayes(fit2)
qqt(efit2$t, df = efit2$df.prior + efit2$df.residual, pch = 16, 
    cex = 0.2)


###################################################
### chunk number 31: 
###################################################
options(digits = 3)
topTable(efit2, number = 50)


###################################################
### chunk number 32: 
###################################################
## Get & store results with & without weights
topvals2 <- topTable(efit2, number = 50)
cbind(row.names(topvals), row.names(topvals2))


###################################################
### chunk number 33: 
###################################################
sum(row.names(topvals)%in%row.names(topvals2))


###################################################
### chunk number 34: 
###################################################
imgplot(coralRG$R[, 1], layout = coralRG$printer)


